==> lxqt-panel_2.1.4.orig.tar.xz: lxqt-panel-2.1.4/plugin-statusnotifier/translations/statusnotifier_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Paràmetres del notificador d&apos;estat</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="25"/>
        <source>Reverse the order of items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="39"/>
        <location filename="../statusnotifierconfiguration.ui" line="49"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Un element d&apos;ocultació automàtica romandrà visible durant aquest període si necessita atenció.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="42"/>
        <source>Attention period:</source>
        <translation>Període d&apos;atenció:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="52"/>
        <source> minute(s)</source>
        <translation> minut(s)</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="83"/>
        <source>Change visibility of items</source>
        <translation>Canvia la visibilitat dels elements</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="96"/>
        <source>Item</source>
        <translation>Element</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="101"/>
        <source>Visibility</source>
        <translation>Visibilitat</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always show</source>
        <translation>Mostra sempre</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Auto-hide</source>
        <translation>Oculta automàticament</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always hide</source>
        <translation>Oculta sempre</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.3.2.orig.tar.xz: lxqt-panel-2.3.2/plugin-statusnotifier/translations/statusnotifier_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Paràmetres del notificador d&apos;estat</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="25"/>
        <source>Reverse the order of items</source>
        <translation>Inverteix l&apos;ordre dels elements</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="39"/>
        <location filename="../statusnotifierconfiguration.ui" line="49"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Un element d&apos;ocultació automàtica romandrà visible durant aquest període si necessita atenció.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="42"/>
        <source>Attention period:</source>
        <translation>Període d&apos;atenció:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="52"/>
        <source> minute(s)</source>
        <translation> minut(s)</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="83"/>
        <source>Change visibility of items</source>
        <translation>Canvia la visibilitat dels elements</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="96"/>
        <source>Item</source>
        <translation>Element</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="101"/>
        <source>Visibility</source>
        <translation>Visibilitat</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always show</source>
        <translation>Mostra sempre</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Auto-hide</source>
        <translation>Oculta automàticament</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always hide</source>
        <translation>Oculta sempre</translation>
    </message>
</context>
</TS>
